Range-v3: ranges::v3::empty_fn Struct Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Public Member Functions | List of all members
ranges::v3::empty_fn Struct Reference
Core

## Public Member Functions
template<typename Rng , requires = (Range<Rng>())>
bool | operator() (Rng &&rng) const

## Member Function Documentation

## ◆ operator()()

template<typename Rng , requires = (Range<Rng>())>

bool ranges::v3::empty_fn::operator() | ( | Rng && | rng | ) | const

Returns
  `begin(rng) == end(rng)`

References ranges::v3::begin, and ranges::v3::end.